#! /usr/bin/python3
# nautilus-scripts-manager
#
# nautilus-scripts-manager is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 3.
#
# nautilus-scripts-manager is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with nautilus-scripts-manager; if not, write to the Free Software Foundation,
# Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# Copyright © 2011-2014 Pietro Battiston <me@pietrobattiston.it>

from gi.repository import Gtk

class Ui(object):
    def __init__(self, APP, filename):
        self._builder = Gtk.Builder()
        self._builder.set_translation_domain(APP)
        self._builder.add_from_file(filename)
    
    def __getattr__(self, attr_name):
        try:
            return object.__getattribute__(self, attr_name)
        except AttributeError:
            obj = self._builder.get_object(attr_name)
            if obj:
                self.obj = obj
                return obj
            else:
                raise AttributeError("no object named \"%s\" in the GUI." % attr_name)



#!/usr/bin/env python

from os import listdir, path, mkdir
from distutils.core import setup
import sys

dist = setup(name='Nautilus scripts manager',
      version='2.0',
      description='Small app to manage Nautilus scripts',
      license='GPL',
      author='Pietro Battiston',
      author_email='me@pietrobattiston.it',
      url='http://www.pietrobattiston.it/nautilus-scripts-manager',
      scripts=['nautilus-scripts-manager'],
      py_modules=['nautilus_scripts_manager_ui'],
      data_files=[('share/nautilus-scripts-manager/stuff', ['stuff/logo.svg', 'stuff/UI.glade']),
				  ('share/pixmaps', ['stuff/nautilus-scripts-manager.svg']),
				  ('share/applications', ['stuff/nautilus-scripts-manager.desktop'])]+
					[('share/locale/'+lang+'/LC_MESSAGES/', ['locale/'+lang+'/LC_MESSAGES/nautilus-scripts-manager.mo'] ) for lang in listdir('locale')],
      classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: X11 Applications :: GTK',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Topic :: Desktop Environment :: Gnome',
        'Topic :: Desktop Environment :: Window Managers :: MetaCity',
        'Topic :: Utilities',
        ]    
     )

if 'install' in dist.command_options:
    if 'prefix' in dist.command_options['install']:
        prefix = dist.command_options['install']['prefix'][1]
    else:
        prefix = sys.prefix

    # "prefix" usually starts with a "/", which disturbs our "path.join()"s below:
    if prefix.startswith('/'):
        prefix = prefix[1:]

    if prefix.endswith('/usr/local'):
        # We don't want /usr/local/nautilus-scripts; it (still) wouldn't be recognized by nautilus-script(s)-manager.
        prefix = prefix[:-6]
        # However we don't want to hardcode '/usr', since i.e. debian packages first
        # installs to a bogus directory.

    if 'root' in dist.command_options['install']:
        root = dist.command_options['install']['root'][1]
    else:
        root = '/'

    scripts_dir = path.join(root, prefix, 'share/nautilus-scripts/')

    if not path.exists(scripts_dir):
        mkdir(scripts_dir)
